==> code-saturne_5.3.2%2Brepack.orig.tar.gz: code-saturne-5.3.2.orig/salome/cfd_study/src/CFDSTUDYGUI/CFDSTUDY_images.ts <==
<!DOCTYPE TS><TS>
    <context>
        <name>@default</name>
        <message>
            <source>NEW_CFDSTUDY_STUDY_ICON</source>
            <translation>NewTreeCreate.png</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_STUDY_ICON</source>
            <translation>SetTreeLocation.png</translation>
        </message>
        <message>
            <source>ADD_CFDSTUDY_CASE_ICON</source>
            <translation>CaseAdd.png</translation>
        </message>
        <message>
            <source>EDIT_CFDSTUDY_CASE_ICON</source>
            <translation>CaseEdit.png</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_CASE_ICON</source>
            <translation>CaseRun.png</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_GUI_ICON</source>
            <translation>LaunchGUI.png</translation>
        </message>
        <message>
            <source>LAUNCH_GUI_WITH_OPTION_ICON</source>
            <translation>LaunchGUIwithOptions.png</translation>
        </message>
        <message>
            <source>UPDATE_CFDSTUDY_OBJBROWSER_ICON</source>
            <translation>UpdateObjBrowser.png</translation>
        </message>
        <message>
            <source>INFO_CFDSTUDY_ICON</source>
            <translation>InfoCFDSTUDY.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_UNKNOWN_OBJ_ICON</source>
            <translation>UnknownDocument.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_CASE_OBJ_ICON</source>
            <translation>Case.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_CASE_IN_PROC_OBJ_ICON</source>
            <translation>CaseInProcess.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FOLDER_OBJ_ICON</source>
            <translation>Folder.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FOLDER_RED_OBJ_ICON</source>
            <translation>FolderRed.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_DOCUMENT_OBJ_ICON</source>
            <translation>Document.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_EDIT_DOCUMENT_OBJ_ICON</source>
            <translation>EditableDocument.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_EXECUTABLE_OBJ_ICON</source>
            <translation>Executable.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_OPENED_FOLDER_OBJ_ICON</source>
            <translation>OpenedFolder.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_STUDY_OBJ_ICON</source>
            <translation>Study.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_DATA_XML_FILE_OBJ_ICON</source>
            <translation>LaunchGUI.png</translation>
        </message>
        <message>
            <source>MESH_OBJ_ICON</source>
            <translation>mesh.png</translation>
        </message>
        <message>
            <source>MESH_TREE_OBJ_ICON</source>
            <translation>mesh_tree_mesh.png</translation>
        </message>
        <message>
            <source>MESH_GROUP_OBJ_ICON</source>
            <translation>mesh_group.png</translation>
        </message>
        <message>
            <source>MESH_GROUP_TREE_OBJ_ICON</source>
            <translation>mesh_tree_group.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_SCRIPT_LOG_OBJ_ICON</source>
            <translation>TmpFile.png</translation>
        </message>
        <message>
            <source>MOVE_ACTION_ICON</source>
            <translation>MoveFile.png</translation>
        </message>
        <message>
            <source>VIEW_ACTION_ICON</source>
            <translation>ViewFile.png</translation>
        </message>
        <message>
            <source>EDIT_ACTION_ICON</source>
            <translation>EditFile.png</translation>
        </message>
        <message>
            <source>DISPLAY_IMAGE_ACTION_ICON</source>
            <translation>ViewFile.png</translation>
        </message>
        <message>
            <source>MOVE_FOLDER_ACTION_ICON</source>
            <translation>MoveFolder.png</translation>
        </message>
        <message>
            <source>DELETE_ACTION_ICON</source>
            <translation>Delete.png</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_ICON</source>
            <translation>Delete.png</translation>
        </message>
        <message>
            <source>CLOSE_ACTION_ICON</source>
            <translation>Close.png</translation>
        </message>
        <message>
            <source>CLOSE_CFD_GUI_ACTION_ICON</source>
            <translation>CloseGui.png</translation>
        </message>
        <message>
            <source>UNDO_CFD_GUI_ACTION_ICON</source>
            <translation>edit-undo.png</translation>
        </message>
        <message>
            <source>REDO_CFD_GUI_ACTION_ICON</source>
            <translation>edit-redo.png</translation>
        </message>
        <message>
            <source>PREPRO_MODE_CFD_GUI_ACTION_ICON</source>
            <translation>prepro-mode.png</translation>
        </message>
        <message>
            <source>CALCULATION_MODE_CFD_GUI_ACTION_ICON</source>
            <translation>calc-mode.png</translation>
        </message>
        <message>
            <source>OPENTURNS_MODE_CFD_GUI_ACTION_ICON</source>
            <translation>ot-logo.png</translation>
        </message>
        <message>
            <source>OPENEXISTINGCASEFILEXML_CFD_GUI_ACTION_ICON</source>
            <translation>LaunchGUIwithOptions.png</translation>
        </message>

        <message>
            <source>CHECK_COMPILATION_ACTION_ICON</source>
            <translation>CheckCompilation.png</translation>
        </message>
        <message>
            <source>POST_FILE_ICON</source>
            <translation>VISU_Plot.png</translation>
        </message>
        <message>
            <source>VISU_OBJ_ICON</source>
            <translation>paravisFile.png</translation>
        </message>
        <message>
            <source>EXPORT_IN_POSTPRO_ACTION_ICON</source>
            <translation>VISU_Module_Export.png</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_ICON</source>
            <translation>SMESH_Module_Export.png</translation>
        </message>
        <message>
            <source>ECS_CONVERT_ACTION_ICON</source>
            <translation>MED_Module_Convert.png</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_ICON</source>
            <translation>RunScript.png</translation>
        </message>
        <message>
            <source>SOLVER_SAVE_ACTION_ICON</source>
            <translation>Save.png</translation>
        </message>
        <message>
            <source>SOLVER_SAVEAS_ACTION_ICON</source>
            <translation>SaveAs.png</translation>
        </message>
    </context>
</TS>

==> code-saturne_6.3.0%2Brepack.orig.tar.gz: code-saturne-6.3.0.orig/salome/cfd_study/src/CFDSTUDYGUI/CFDSTUDY_images.ts <==
<!DOCTYPE TS><TS>
    <context>
        <name>@default</name>
        <message>
            <source>NEW_CFDSTUDY_STUDY_ICON</source>
            <translation>NewTreeCreate.png</translation>
        </message>
        <message>
            <source>SET_CFDSTUDY_STUDY_ICON</source>
            <translation>SetTreeLocation.png</translation>
        </message>
        <message>
            <source>ADD_CFDSTUDY_CASE_ICON</source>
            <translation>CaseAdd.png</translation>
        </message>
        <message>
            <source>EDIT_CFDSTUDY_CASE_ICON</source>
            <translation>CaseEdit.png</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_CASE_ICON</source>
            <translation>CaseRun.png</translation>
        </message>
        <message>
            <source>LAUNCH_CFDSTUDY_GUI_ICON</source>
            <translation>LaunchGUI.png</translation>
        </message>
        <message>
            <source>LAUNCH_GUI_WITH_OPTION_ICON</source>
            <translation>LaunchGUIwithOptions.png</translation>
        </message>
        <message>
            <source>UPDATE_CFDSTUDY_OBJBROWSER_ICON</source>
            <translation>UpdateObjBrowser.png</translation>
        </message>
        <message>
            <source>INFO_CFDSTUDY_ICON</source>
            <translation>InfoCFDSTUDY.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_UNKNOWN_OBJ_ICON</source>
            <translation>UnknownDocument.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_CASE_OBJ_ICON</source>
            <translation>Case.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_CASE_IN_PROC_OBJ_ICON</source>
            <translation>CaseInProcess.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FOLDER_OBJ_ICON</source>
            <translation>Folder.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FOLDER_RED_OBJ_ICON</source>
            <translation>FolderRed.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_DOCUMENT_OBJ_ICON</source>
            <translation>Document.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_EDIT_DOCUMENT_OBJ_ICON</source>
            <translation>EditableDocument.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_EXECUTABLE_OBJ_ICON</source>
            <translation>Executable.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_OPENED_FOLDER_OBJ_ICON</source>
            <translation>OpenedFolder.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_STUDY_OBJ_ICON</source>
            <translation>Study.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_DATA_XML_FILE_OBJ_ICON</source>
            <translation>LaunchGUI.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_COMPILER_OBJ_ICON</source>
            <translation>compiler-icon.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FILE_EDITOR_OBJ_ICON</source>
            <translation>src_editor-icon.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FILE_VIEWER_OBJ_ICON</source>
            <translation>resu_viewer-icon.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_FILE_TRANSFER_OBJ_ICON</source>
            <translation>file_transfer.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_SOLVER_LAUNCH_ICON</source>
            <translation>run_button.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_SOLVER_LAUNCH_OT_ICON</source>
            <translation>ot-logo.png</translation>
        </message>
        <message>
            <source>MESH_OBJ_ICON</source>
            <translation>mesh.png</translation>
        </message>
        <message>
            <source>MESH_TREE_OBJ_ICON</source>
            <translation>mesh_tree_mesh.png</translation>
        </message>
        <message>
            <source>MESH_GROUP_OBJ_ICON</source>
            <translation>mesh_group.png</translation>
        </message>
        <message>
            <source>MESH_GROUP_TREE_OBJ_ICON</source>
            <translation>mesh_tree_group.png</translation>
        </message>
        <message>
            <source>CFDSTUDY_SCRIPT_LOG_OBJ_ICON</source>
            <translation>TmpFile.png</translation>
        </message>
        <message>
            <source>MOVE_ACTION_ICON</source>
            <translation>MoveFile.png</translation>
        </message>
        <message>
            <source>VIEW_ACTION_ICON</source>
            <translation>ViewFile.png</translation>
        </message>
        <message>
            <source>EDIT_ACTION_ICON</source>
            <translation>EditFile.png</translation>
        </message>
        <message>
            <source>DISPLAY_IMAGE_ACTION_ICON</source>
            <translation>ViewFile.png</translation>
        </message>
        <message>
            <source>MOVE_FOLDER_ACTION_ICON</source>
            <translation>MoveFolder.png</translation>
        </message>
        <message>
            <source>DELETE_ACTION_ICON</source>
            <translation>Delete.png</translation>
        </message>
        <message>
            <source>REMOVE_ACTION_ICON</source>
            <translation>Delete.png</translation>
        </message>
        <message>
            <source>CLOSE_ACTION_ICON</source>
            <translation>Close.png</translation>
        </message>
        <message>
            <source>CLOSE_CFD_GUI_ACTION_ICON</source>
            <translation>CloseGui.png</translation>
        </message>
        <message>
            <source>UNDO_CFD_GUI_ACTION_ICON</source>
            <translation>edit-undo.png</translation>
        </message>
        <message>
            <source>REDO_CFD_GUI_ACTION_ICON</source>
            <translation>edit-redo.png</translation>
        </message>
        <message>
            <source>OPENTURNS_MODE_CFD_GUI_ACTION_ICON</source>
            <translation>ot-logo.png</translation>
        </message>
        <message>
            <source>OPENEXISTINGCASEFILEXML_CFD_GUI_ACTION_ICON</source>
            <translation>LaunchGUIwithOptions.png</translation>
        </message>

        <message>
            <source>CHECK_COMPILATION_ACTION_ICON</source>
            <translation>CheckCompilation.png</translation>
        </message>
        <message>
            <source>POST_FILE_ICON</source>
            <translation>VISU_Plot.png</translation>
        </message>
        <message>
            <source>VISU_OBJ_ICON</source>
            <translation>paravisFile.png</translation>
        </message>
        <message>
            <source>EXPORT_IN_POSTPRO_ACTION_ICON</source>
            <translation>VISU_Module_Export.png</translation>
        </message>
        <message>
            <source>EXPORT_IN_SMESH_ACTION_ICON</source>
            <translation>SMESH_Module_Export.png</translation>
        </message>
        <message>
            <source>ECS_CONVERT_ACTION_ICON</source>
            <translation>MED_Module_Convert.png</translation>
        </message>
        <message>
            <source>RUN_SCRIPT_ACTION_ICON</source>
            <translation>RunScript.png</translation>
        </message>
        <message>
            <source>SOLVER_SAVE_ACTION_ICON</source>
            <translation>Save.png</translation>
        </message>
    </context>
</TS>
